define("ember-cli-scrolling-content", ["ember-cli-scrolling-content/index","exports"], function(__index__, __exports__) {
  "use strict";
  Object.keys(__index__).forEach(function(key){
    __exports__[key] = __index__[key];
  });
});

define('ember-cli-scrolling-content/components/scroll-content', ['exports', 'ember', 'ember-cli-scrolling-content/templates/components/scroll-content'], function (exports, Ember, layout) {

  'use strict';

  exports['default'] = Ember['default'].Component.extend({
    layout: layout['default'],
    classNames: 'scroll-content',

    speed: 1,
    dependsOn: null,

    mouseEnter: function() {
      this.$().stop();
      var scrollRatio = (this.get('offset') - this.$().scrollLeft()) / this.get('offset');
      this.$().animate({scrollLeft: this.get('offset')}, this.get('duration') * scrollRatio, 'linear');
    },

    mouseLeave: function() {
      this.$().stop();
      var scrollRatio = this.$().scrollLeft() / this.get('offset');
      this.$().animate({scrollLeft: 0}, this.get('duration') * scrollRatio, 'linear');
    },

    innerWidth: function() {
      this.$().css({ 'overflow': 'visible', 'float': 'left', });
      var innerWidth = this.$().width();
      this.$().css({'overflow': 'hidden', 'float': 'none'});
      return innerWidth;
    }.property('dependsOn'),

    outerWidth: function() {
      return this.$().width();
    }.property('dependsOn'),

    offset: function() {
      return this.get('innerWidth') - this.get('outerWidth');
    }.property('innerWidth', 'outerWidth'),

    duration: function() {
      return this.get('offset') * 10 / this.get('speed');
    }.property('offset', 'speed'),

    didInsertElement: function() {
      this.$().css({
        'display': 'block',
        'white-space': 'nowrap',
        'overflow': 'hidden',
        'float': 'none',
      });
    }
  });

});
define('ember-cli-scrolling-content/components/scrolling-content', ['exports', 'ember', 'ember-cli-scrolling-content/templates/components/scrolling-content'], function (exports, Ember, layout) {

  'use strict';

  exports['default'] = Ember['default'].Component.extend({
    layout: layout['default'],
    classNames: 'scrolling-content',

    speed: 1,
    dependsOn: null,
    scrollForward: false,
    hover: true,

    scroll: function(forward) {
      var scrollRatio, _this = this;
      this.$().stop();

      if (forward) {
        scrollRatio = (this.get('offset') - this.$().scrollLeft()) / this.get('offset');
      } else {
        scrollRatio = this.$().scrollLeft() / this.get('offset');
      }

      this.$().animate(
        {scrollLeft: forward ? this.get('offset') : 0},
        this.get('duration') * scrollRatio,
        'linear',
        function() {
          if (forward) {
            _this.sendAction('didScrollForward');
          } else {
            _this.sendAction('didScrollBackward');
          }
        }
      );
    },

    changeDirection: function() {
      this.scroll( this.get('scrollForward') );
    }.observes('scrollForward'),

    mouseEnter: function() {
      if (this.get('hover')) {
        this.set('scrollForward', true);
      }
    },

    mouseLeave: function() {
      if (this.get('hover')) {
        this.set('scrollForward', false);
      }
    },

    innerWidth: function() {
      this.$().css({ 'overflow': 'visible', 'float': 'left', });
      var innerWidth = this.$().width();
      this.$().css({'overflow': 'hidden', 'float': 'none'});
      return innerWidth;
    }.property('dependsOn'),

    outerWidth: function() {
      return this.$().width();
    }.property('dependsOn'),

    offset: function() {
      return this.get('innerWidth') - this.get('outerWidth');
    }.property('innerWidth', 'outerWidth'),

    duration: function() {
      return this.get('offset') * 10 / this.get('speed');
    }.property('offset', 'speed'),

    didInsertElement: function() {
      this.$().css({
        'display': 'block',
        'white-space': 'nowrap',
        'overflow': 'hidden',
        'float': 'none',
      });
    }
  });

});
define('ember-cli-scrolling-content/templates/components/scroll-content', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.HTMLBars.template((function() {
    return {
      isHTMLBars: true,
      blockParams: 0,
      cachedFragment: null,
      hasRendered: false,
      build: function build(dom) {
        var el0 = dom.createDocumentFragment();
        var el1 = dom.createTextNode("");
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("\n");
        dom.appendChild(el0, el1);
        return el0;
      },
      render: function render(context, env, contextualElement) {
        var dom = env.dom;
        var hooks = env.hooks, content = hooks.content;
        dom.detectNamespace(contextualElement);
        var fragment;
        if (env.useFragmentCache && dom.canClone) {
          if (this.cachedFragment === null) {
            fragment = this.build(dom);
            if (this.hasRendered) {
              this.cachedFragment = fragment;
            } else {
              this.hasRendered = true;
            }
          }
          if (this.cachedFragment) {
            fragment = dom.cloneNode(this.cachedFragment, true);
          }
        } else {
          fragment = this.build(dom);
        }
        if (this.cachedFragment) { dom.repairClonedNode(fragment,[0]); }
        var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
        content(env, morph0, context, "yield");
        return fragment;
      }
    };
  }()));

});
define('ember-cli-scrolling-content/templates/components/scrolling-content', ['exports'], function (exports) {

  'use strict';

  exports['default'] = Ember.HTMLBars.template((function() {
    return {
      isHTMLBars: true,
      blockParams: 0,
      cachedFragment: null,
      hasRendered: false,
      build: function build(dom) {
        var el0 = dom.createDocumentFragment();
        var el1 = dom.createTextNode("");
        dom.appendChild(el0, el1);
        var el1 = dom.createTextNode("\n");
        dom.appendChild(el0, el1);
        return el0;
      },
      render: function render(context, env, contextualElement) {
        var dom = env.dom;
        var hooks = env.hooks, content = hooks.content;
        dom.detectNamespace(contextualElement);
        var fragment;
        if (env.useFragmentCache && dom.canClone) {
          if (this.cachedFragment === null) {
            fragment = this.build(dom);
            if (this.hasRendered) {
              this.cachedFragment = fragment;
            } else {
              this.hasRendered = true;
            }
          }
          if (this.cachedFragment) {
            fragment = dom.cloneNode(this.cachedFragment, true);
          }
        } else {
          fragment = this.build(dom);
        }
        if (this.cachedFragment) { dom.repairClonedNode(fragment,[0]); }
        var morph0 = dom.createMorphAt(fragment,0,1,contextualElement);
        content(env, morph0, context, "yield");
        return fragment;
      }
    };
  }()));

});//# sourceMappingURL=addons.map